import { configureStore, combineReducers } from "@reduxjs/toolkit";
import { TypedUseSelectorHook, useDispatch, useSelector } from "react-redux";
import { ProductSlice } from "./Slices/product.slice";
import { BasketSlice } from "./Slices/basket.slice";
import { ProductService } from "./Services/product.service";

const rootReducer = combineReducers({
    product: ProductSlice.reducer,
    basket: BasketSlice.reducer,
    [ProductService.reducerPath]: ProductService.reducer
});

export const store = configureStore({
    reducer: rootReducer,
    middleware: (getDefaultMiddleware) =>
        getDefaultMiddleware().concat(ProductService.middleware),
});

type RootState = ReturnType<typeof store.getState>;
type AppDispatch = typeof store.dispatch;

export const useAppDispatch: () => AppDispatch = useDispatch
export const useAppSelector: TypedUseSelectorHook<RootState> = useSelector